@@ -3,6 +3,7 @@ import { shallow } from 'enzyme';
 import { FolderPicker } from './FolderPicker';
 
 jest.mock('@grafana/runtime', () => ({
+  ...((jest.requireActual('@grafana/runtime') as unknown) as object),
   getBackendSrv: () => ({
     search: jest.fn(() => [
       { title: 'Dash 1', id: 'A' },
@@ -11,6 +12,10 @@ jest.mock('@grafana/runtime', () => ({
   }),
 }));
 
+jest.mock('../../config', () => ({
+  getConfig: () => ({}),
+}));
+
 jest.mock('app/core/services/context_srv', () => ({
   contextSrv: {
     user: { orgId: 1 },
