@@ -1,8 +1,7 @@
-///<reference path="../../headers/common.d.ts" />
-
 import coreModule from 'app/core/core_module';
+import { backendSrv } from '../services/backend_srv';
 
-var template = `
+const template = `
 <select class="gf-form-input" ng-model="ctrl.model" ng-options="f.value as f.text for f in ctrl.options"></select>
 `;
 
@@ -10,16 +9,12 @@ export class DashboardSelectorCtrl {
   model: any;
   options: any;
 
-  /** @ngInject */
-  constructor(private backendSrv) {
-  }
-
   $onInit() {
-    this.options = [{value: 0, text: 'Default'}];
+    this.options = [{ value: 0, text: 'Default' }];
 
-    return this.backendSrv.search({starred: true}).then(res => {
-      res.forEach(dash => {
-        this.options.push({value: dash.id, text: dash.title});
+    return backendSrv.search({ starred: true }).then((res) => {
+      res.forEach((dash) => {
+        this.options.push({ value: dash.id, text: dash.title });
       });
     });
   }
@@ -33,8 +28,8 @@ export function dashboardSelector() {
     controllerAs: 'ctrl',
     template: template,
     scope: {
-      model: '='
-    }
+      model: '=',
+    },
   };
 }
 
