@@ -1,7 +1,9 @@
-import React from 'react';
+import React, { useEffect, useState } from 'react';
 import { config, GrafanaBootConfig } from '@grafana/runtime';
-import { ThemeContext, getTheme } from '@grafana/ui';
-import { GrafanaThemeType } from '@grafana/data';
+import { ThemeContext } from '@grafana/ui';
+import { appEvents } from '../core';
+import { ThemeChangedEvent } from 'app/types/events';
+import { GrafanaTheme } from '@grafana/data';
 
 export const ConfigContext = React.createContext<GrafanaBootConfig>(config);
 export const ConfigConsumer = ConfigContext.Consumer;
@@ -10,23 +12,22 @@ export const provideConfig = (component: React.ComponentType<any>) => {
   const ConfigProvider = (props: any) => (
     <ConfigContext.Provider value={config}>{React.createElement(component, { ...props })}</ConfigContext.Provider>
   );
-
   return ConfigProvider;
 };
 
-export const getCurrentThemeName = () =>
-  config.bootData.user.lightTheme ? GrafanaThemeType.Light : GrafanaThemeType.Dark;
-
-export const getCurrentTheme = () => getTheme(getCurrentThemeName());
-
 export const ThemeProvider = ({ children }: { children: React.ReactNode }) => {
-  return (
-    <ConfigConsumer>
-      {(config) => {
-        return <ThemeContext.Provider value={getCurrentTheme()}>{children}</ThemeContext.Provider>;
-      }}
-    </ConfigConsumer>
-  );
+  const [theme, setTheme] = useState<GrafanaTheme>(config.theme);
+
+  useEffect(() => {
+    const sub = appEvents.subscribe(ThemeChangedEvent, (event) => {
+      config.theme = event.payload;
+      setTheme(event.payload);
+    });
+
+    return () => sub.unsubscribe();
+  }, []);
+
+  return <ThemeContext.Provider value={theme}>{children}</ThemeContext.Provider>;
 };
 
 export const provideTheme = (component: React.ComponentType<any>) => {
