@@ -6,7 +6,14 @@ import { Subscription } from 'rxjs';
 
 import { FieldConfigSource, GrafanaTheme } from '@grafana/data';
 import { selectors } from '@grafana/e2e-selectors';
-import { Button, HorizontalGroup, Icon, RadioButtonGroup, stylesFactory } from '@grafana/ui';
+import {
+  HorizontalGroup,
+  ModalsController,
+  PageToolbar,
+  RadioButtonGroup,
+  stylesFactory,
+  ToolbarButton,
+} from '@grafana/ui';
 
 import config from 'app/core/config';
 import { appEvents } from 'app/core/core';
@@ -15,15 +22,18 @@ import { calculatePanelSize } from './utils';
 import { PanelEditorTabs } from './PanelEditorTabs';
 import { DashNavTimeControls } from '../DashNav/DashNavTimeControls';
 import { OptionsPaneContent } from './OptionsPaneContent';
-import { DashNavButton } from 'app/features/dashboard/components/DashNav/DashNavButton';
 import { SubMenuItems } from 'app/features/dashboard/components/SubMenu/SubMenuItems';
-import { BackButton } from 'app/core/components/BackButton/BackButton';
-import { PageToolbar } from 'app/core/components/PageToolbar/PageToolbar';
 import { SplitPaneWrapper } from 'app/core/components/SplitPaneWrapper/SplitPaneWrapper';
 import { SaveDashboardModalProxy } from '../SaveDashboard/SaveDashboardModalProxy';
 import { DashboardPanel } from '../../dashgrid/DashboardPanel';
 
-import { initPanelEditor, panelEditorCleanUp, updatePanelEditorUIState } from './state/actions';
+import {
+  exitPanelEditor,
+  initPanelEditor,
+  panelEditorCleanUp,
+  updatePanelEditorUIState,
+  updateSourcePanel,
+} from './state/actions';
 
 import { updateTimeZoneForSession } from 'app/features/profile/state/reducers';
 import { updateLocation } from 'app/core/reducers/location';
@@ -37,6 +47,16 @@ import { CoreEvents, StoreState } from 'app/types';
 import { DisplayMode, displayModes, PanelEditorTab } from './types';
 import { DashboardModel, PanelModel } from '../../state';
 import { PanelOptionsChangedEvent } from 'app/types/events';
+import { UnlinkModal } from '../../../library-panels/components/UnlinkModal/UnlinkModal';
+import { SaveLibraryPanelModal } from 'app/features/library-panels/components/SaveLibraryPanelModal/SaveLibraryPanelModal';
+import { isPanelModelLibraryPanel } from '../../../library-panels/guard';
+import { getLibraryPanelConnectedDashboards } from '../../../library-panels/state/api';
+import {
+  createPanelLibraryErrorNotification,
+  createPanelLibrarySuccessNotification,
+  saveAndRefreshLibraryPanel,
+} from '../../../library-panels/utils';
+import { notifyApp } from '../../../../core/actions';
 
 interface OwnProps {
   dashboard: DashboardModel;
@@ -61,10 +81,13 @@ const mapStateToProps = (state: StoreState) => {
 const mapDispatchToProps = {
   updateLocation,
   initPanelEditor,
+  exitPanelEditor,
+  updateSourcePanel,
   panelEditorCleanUp,
   setDiscardChanges,
   updatePanelEditorUIState,
   updateTimeZoneForSession,
+  notifyApp,
 };
 
 const connector = connect(mapStateToProps, mapDispatchToProps);
@@ -96,13 +119,6 @@ export class PanelEditorUnconnected extends PureComponent<Props> {
     this.forceUpdate();
   };
 
-  onPanelExit = () => {
-    this.props.updateLocation({
-      query: { editPanel: null, tab: null },
-      partial: true,
-    });
-  };
-
   onDiscard = () => {
     this.props.setDiscardChanges(true);
     this.props.updateLocation({
@@ -122,6 +138,44 @@ export class PanelEditorUnconnected extends PureComponent<Props> {
     });
   };
 
+  onSaveLibraryPanel = async () => {
+    if (!isPanelModelLibraryPanel(this.props.panel)) {
+      // New library panel, no need to display modal
+      return;
+    }
+
+    if (this.props.panel.libraryPanel.meta.connectedDashboards === 0) {
+      return;
+    }
+
+    const connectedDashboards = await getLibraryPanelConnectedDashboards(this.props.panel.libraryPanel.uid);
+    if (connectedDashboards.length === 1 && connectedDashboards.indexOf(this.props.dashboard.id) !== -1) {
+      try {
+        await saveAndRefreshLibraryPanel(this.props.panel, this.props.dashboard.meta.folderId!);
+        this.props.updateSourcePanel(this.props.panel);
+        this.props.notifyApp(createPanelLibrarySuccessNotification('Library panel saved'));
+      } catch (err) {
+        this.props.notifyApp(createPanelLibraryErrorNotification(`Error saving library panel: "${err.statusText}"`));
+      }
+      return;
+    }
+
+    appEvents.emit(CoreEvents.showModalReact, {
+      component: SaveLibraryPanelModal,
+      props: {
+        panel: this.props.panel,
+        folderId: this.props.dashboard.meta.folderId,
+        isOpen: true,
+        onConfirm: () => {
+          // need to update the source panel here so that when
+          // the user exits the panel editor they aren't prompted to save again
+          this.props.updateSourcePanel(this.props.panel);
+        },
+        onDiscard: this.onDiscard,
+      },
+    });
+  };
+
   onChangeTab = (tab: PanelEditorTab) => {
     this.props.updateLocation({ query: { tab: tab.id }, partial: true });
   };
@@ -140,14 +194,13 @@ export class PanelEditorUnconnected extends PureComponent<Props> {
     this.props.panel.updateOptions(options);
   };
 
-  onPanelConfigChanged = (configKey: string, value: any) => {
-    // @ts-ignore
-    this.props.panel[configKey] = value;
+  onPanelConfigChanged = (configKey: keyof PanelModel, value: any) => {
+    this.props.panel.setProperty(configKey, value);
     this.props.panel.render();
     this.forceUpdate();
   };
 
-  onDisplayModeChange = (mode: DisplayMode) => {
+  onDisplayModeChange = (mode?: DisplayMode) => {
     const { updatePanelEditorUIState } = this.props;
     updatePanelEditorUIState({
       mode: mode,
@@ -237,13 +290,9 @@ export class PanelEditorUnconnected extends PureComponent<Props> {
               onChangeTimeZone={updateTimeZoneForSession}
             />
             {!uiState.isPanelOptionsVisible && (
-              <DashNavButton
-                onClick={this.onTogglePanelOptions}
-                tooltip="Open options pane"
-                classSuffix="close-options"
-              >
-                <Icon name="angle-left" /> <span style={{ paddingLeft: '6px' }}>Show options</span>
-              </DashNavButton>
+              <ToolbarButton onClick={this.onTogglePanelOptions} tooltip="Open options pane" icon="angle-left">
+                Show options
+              </ToolbarButton>
             )}
           </HorizontalGroup>
         </HorizontalGroup>
@@ -252,24 +301,74 @@ export class PanelEditorUnconnected extends PureComponent<Props> {
   }
 
   renderEditorActions() {
-    return [
-      <Button
+    let editorActions = [
+      <ToolbarButton
         icon="cog"
         onClick={this.onOpenDashboardSettings}
-        variant="secondary"
         title="Open dashboard settings"
         key="settings"
       />,
-      <Button onClick={this.onDiscard} variant="secondary" title="Undo all changes" key="discard">
+      <ToolbarButton onClick={this.onDiscard} title="Undo all changes" key="discard">
         Discard
-      </Button>,
-      <Button onClick={this.onSaveDashboard} variant="secondary" title="Apply changes and save dashboard" key="save">
-        Save
-      </Button>,
-      <Button onClick={this.onPanelExit} title="Apply changes and go back to dashboard" key="apply">
+      </ToolbarButton>,
+      this.props.panel.libraryPanel ? (
+        <ToolbarButton
+          onClick={this.onSaveLibraryPanel}
+          variant="primary"
+          title="Apply changes and save library panel"
+          key="save-panel"
+        >
+          Save library panel
+        </ToolbarButton>
+      ) : (
+        <ToolbarButton onClick={this.onSaveDashboard} title="Apply changes and save dashboard" key="save">
+          Save
+        </ToolbarButton>
+      ),
+      <ToolbarButton
+        onClick={this.props.exitPanelEditor}
+        variant="primary"
+        title="Apply changes and go back to dashboard"
+        key="apply"
+      >
         Apply
-      </Button>,
+      </ToolbarButton>,
     ];
+
+    if (this.props.panel.libraryPanel) {
+      editorActions.splice(
+        1,
+        0,
+        <ModalsController key="unlink-controller">
+          {({ showModal, hideModal }) => {
+            return (
+              <ToolbarButton
+                onClick={() => {
+                  showModal(UnlinkModal, {
+                    onConfirm: () => {
+                      delete this.props.panel.libraryPanel;
+                      this.props.panel.render();
+                      this.forceUpdate();
+                    },
+                    onDismiss: hideModal,
+                    isOpen: true,
+                  });
+                }}
+                title="Disconnects this panel from the reusable panel so that you can edit it regularly."
+                key="unlink"
+              >
+                Unlink
+              </ToolbarButton>
+            );
+          }}
+        </ModalsController>
+      );
+
+      // Remove "Apply" button
+      editorActions.pop();
+    }
+
+    return editorActions;
   }
 
   renderOptionsPane() {
@@ -308,11 +407,9 @@ export class PanelEditorUnconnected extends PureComponent<Props> {
 
     return (
       <div className={styles.wrapper} aria-label={selectors.components.PanelEditor.General.content}>
-        <PageToolbar
-          title={`${dashboard.title} / Edit Panel`}
-          titlePrefix={<BackButton onClick={this.onPanelExit} surface="panel" />}
-          actions={this.renderEditorActions()}
-        />
+        <PageToolbar title={`${dashboard.title} / Edit Panel`} onGoBack={this.props.exitPanelEditor}>
+          {this.renderEditorActions()}
+        </PageToolbar>
         <div className={styles.verticalSplitPanesWrapper}>
           <SplitPaneWrapper
             leftPaneComponents={this.renderPanelAndEditor(styles)}
