@@ -1,8 +1,5 @@
-// Libraries
 import _ from 'lodash';
-// Utils
-import coreModule from 'app/core/core_module';
-// Types
+import { ILocationService, ITimeoutService } from 'angular';
 import {
   dateMath,
   dateTime,
@@ -13,15 +10,16 @@ import {
   TimeRange,
   toUtc,
 } from '@grafana/data';
-import { ILocationService, ITimeoutService } from 'angular';
+
+import coreModule from 'app/core/core_module';
 import { ContextSrv } from 'app/core/services/context_srv';
 import { DashboardModel } from '../state/DashboardModel';
 import { GrafanaRootScope } from 'app/routes/GrafanaCtrl';
 import { getShiftedTimeRange, getZoomedTimeRange } from 'app/core/utils/timePicker';
 import { appEvents } from '../../../core/core';
 import { CoreEvents } from '../../../types';
-
 import { config } from 'app/core/config';
+import { getRefreshFromUrl } from '../utils/getRefreshFromUrl';
 
 export class TimeSrv {
   time: any;
@@ -151,13 +149,13 @@ export class TimeSrv {
       this.dashboard.refresh = false;
     }
     // but if refresh explicitly set then use that
-    if (params.refresh) {
-      if (!this.contextSrv.isAllowedInterval(params.refresh)) {
-        this.refresh = config.minRefreshInterval;
-      } else {
-        this.refresh = params.refresh || this.refresh;
-      }
-    }
+    this.refresh = getRefreshFromUrl({
+      params,
+      currentRefresh: this.refresh,
+      refreshIntervals: this.dashboard?.timepicker?.refresh_intervals,
+      isAllowedIntervalFn: this.contextSrv.isAllowedInterval,
+      minRefreshInterval: config.minRefreshInterval,
+    });
   }
 
   private routeUpdated() {
