@@ -1,9 +1,12 @@
 import InfluxDatasource from './datasource';
 import { InfluxQueryCtrl } from './query_ctrl';
-import { InfluxLogsQueryField } from './components/InfluxLogsQueryField';
 import InfluxStartPage from './components/InfluxStartPage';
 import { DataSourcePlugin } from '@grafana/data';
 import ConfigEditor from './components/ConfigEditor';
+import VariableQueryEditor from './components/VariableQueryEditor';
+
+// This adds a directive that is used in the query editor
+import './components/FluxQueryEditor';
 
 class InfluxAnnotationsQueryCtrl {
   static templateUrl = 'partials/annotations.editor.html';
@@ -13,5 +16,5 @@ export const plugin = new DataSourcePlugin(InfluxDatasource)
   .setConfigEditor(ConfigEditor)
   .setQueryCtrl(InfluxQueryCtrl)
   .setAnnotationQueryCtrl(InfluxAnnotationsQueryCtrl)
-  .setExploreLogsQueryField(InfluxLogsQueryField)
-  .setExploreStartPage(InfluxStartPage);
+  .setVariableQueryEditor(VariableQueryEditor)
+  .setQueryEditorHelp(InfluxStartPage);
