@@ -1,3 +1,4 @@
+import { LokiQuery } from './types';
 /**
  * Just a simple wrapper for a react component that is actually implementing the query editor.
  */
@@ -11,7 +12,9 @@ export class LokiAnnotationsQueryCtrl {
     this.onQueryChange = this.onQueryChange.bind(this);
   }
 
-  onQueryChange(expr: string) {
-    this.annotation.expr = expr;
+  onQueryChange(query: LokiQuery) {
+    this.annotation.expr = query.expr;
+    this.annotation.maxLines = query.maxLines;
+    this.annotation.instant = query.instant;
   }
 }
