@@ -2,22 +2,22 @@
 import React, { ReactNode } from 'react';
 
 import {
-  ButtonCascader,
-  CascaderOption,
   SlatePrism,
   TypeaheadOutput,
   SuggestionsState,
   QueryField,
   TypeaheadInput,
   BracesPlugin,
+  DOMUtil,
+  Icon,
 } from '@grafana/ui';
 
 // Utils & Services
 // dom also includes Element polyfills
 import { Plugin, Node } from 'slate';
+import { LokiLabelBrowser } from './LokiLabelBrowser';
 
 // Types
-import { DOMUtil } from '@grafana/ui';
 import { ExploreQueryFieldProps, AbsoluteTimeRange } from '@grafana/data';
 import { LokiQuery, LokiOptions } from '../types';
 import { LanguageMap, languages as prismLanguages } from 'prismjs';
@@ -30,9 +30,9 @@ function getChooserText(hasSyntax: boolean, hasLogLabels: boolean) {
     return 'Loading labels...';
   }
   if (!hasLogLabels) {
-    return '(No labels found)';
+    return '(No logs found)';
   }
-  return 'Log labels';
+  return 'Log browser';
 }
 
 function willApplySuggestion(suggestion: string, { typeaheadContext, typeaheadText }: SuggestionsState): string {
@@ -64,20 +64,23 @@ function willApplySuggestion(suggestion: string, { typeaheadContext, typeaheadTe
 
 export interface LokiQueryFieldFormProps extends ExploreQueryFieldProps<LokiDatasource, LokiQuery, LokiOptions> {
   history: LokiHistoryItem[];
-  logLabelOptions: CascaderOption[];
-  labelsLoaded: boolean;
   absoluteRange: AbsoluteTimeRange;
-  onLoadOptions: (selectedOptions: CascaderOption[]) => void;
-  onLabelsRefresh?: () => void;
   ExtraFieldElement?: ReactNode;
   runOnBlur?: boolean;
 }
 
-export class LokiQueryFieldForm extends React.PureComponent<LokiQueryFieldFormProps> {
+interface LokiQueryFieldFormState {
+  labelsLoaded: boolean;
+  labelBrowserVisible: boolean;
+}
+
+export class LokiQueryFieldForm extends React.PureComponent<LokiQueryFieldFormProps, LokiQueryFieldFormState> {
   plugins: Plugin[];
 
-  constructor(props: LokiQueryFieldFormProps, context: React.Context<any>) {
-    super(props, context);
+  constructor(props: LokiQueryFieldFormProps) {
+    super(props);
+
+    this.state = { labelsLoaded: false, labelBrowserVisible: false };
 
     this.plugins = [
       BracesPlugin(),
@@ -91,17 +94,14 @@ export class LokiQueryFieldForm extends React.PureComponent<LokiQueryFieldFormPr
     ];
   }
 
-  loadOptions = (selectedOptions: CascaderOption[]) => {
-    this.props.onLoadOptions(selectedOptions);
-  };
+  async componentDidUpdate() {
+    await this.props.datasource.languageProvider.start();
+    this.setState({ labelsLoaded: true });
+  }
 
-  onChangeLogLabels = (values: string[], selectedOptions: CascaderOption[]) => {
-    if (selectedOptions.length === 2) {
-      const key = selectedOptions[0].value;
-      const value = selectedOptions[1].value;
-      const query = `{${key}="${value}"}`;
-      this.onChangeQuery(query, true);
-    }
+  onChangeLogLabels = (selector: string) => {
+    this.onChangeQuery(selector, true);
+    this.setState({ labelBrowserVisible: false });
   };
 
   onChangeQuery = (value: string, override?: boolean) => {
@@ -117,6 +117,10 @@ export class LokiQueryFieldForm extends React.PureComponent<LokiQueryFieldFormPr
     }
   };
 
+  onClickChooserButton = () => {
+    this.setState((state) => ({ labelBrowserVisible: !state.labelBrowserVisible }));
+  };
+
   onTypeahead = async (typeahead: TypeaheadInput): Promise<TypeaheadOutput> => {
     const { datasource } = this.props;
 
@@ -125,48 +129,36 @@ export class LokiQueryFieldForm extends React.PureComponent<LokiQueryFieldFormPr
     }
 
     const lokiLanguageProvider = datasource.languageProvider as LokiLanguageProvider;
-    const { history, absoluteRange } = this.props;
+    const { history } = this.props;
     const { prefix, text, value, wrapperClasses, labelKey } = typeahead;
 
     const result = await lokiLanguageProvider.provideCompletionItems(
       { text, value, prefix, wrapperClasses, labelKey },
-      { history, absoluteRange }
+      { history }
     );
     return result;
   };
 
   render() {
-    const {
-      ExtraFieldElement,
-      query,
-      labelsLoaded,
-      logLabelOptions,
-      onLoadOptions,
-      onLabelsRefresh,
-      datasource,
-      runOnBlur,
-    } = this.props;
-
+    const { ExtraFieldElement, query, datasource, runOnBlur } = this.props;
+    const { labelsLoaded, labelBrowserVisible } = this.state;
     const lokiLanguageProvider = datasource.languageProvider as LokiLanguageProvider;
     const cleanText = datasource.languageProvider ? lokiLanguageProvider.cleanText : undefined;
-    const hasLogLabels = logLabelOptions && logLabelOptions.length > 0;
+    const hasLogLabels = lokiLanguageProvider.getLabelKeys().length > 0;
     const chooserText = getChooserText(labelsLoaded, hasLogLabels);
     const buttonDisabled = !(labelsLoaded && hasLogLabels);
 
     return (
       <>
         <div className="gf-form-inline gf-form-inline--xs-view-flex-column flex-grow-1">
-          <div className="gf-form flex-shrink-0 min-width-5">
-            <ButtonCascader
-              options={logLabelOptions || []}
-              disabled={buttonDisabled}
-              onChange={this.onChangeLogLabels}
-              loadData={onLoadOptions}
-              onPopupVisibleChange={(isVisible) => isVisible && onLabelsRefresh && onLabelsRefresh()}
-            >
-              {chooserText}
-            </ButtonCascader>
-          </div>
+          <button
+            className="gf-form-label query-keyword pointer"
+            onClick={this.onClickChooserButton}
+            disabled={buttonDisabled}
+          >
+            {chooserText}
+            <Icon name={labelBrowserVisible ? 'angle-down' : 'angle-right'} />
+          </button>
           <div className="gf-form gf-form--grow flex-shrink-1 min-width-15">
             <QueryField
               additionalPlugins={this.plugins}
@@ -182,6 +174,11 @@ export class LokiQueryFieldForm extends React.PureComponent<LokiQueryFieldFormPr
             />
           </div>
         </div>
+        {labelBrowserVisible && (
+          <div className="gf-form">
+            <LokiLabelBrowser languageProvider={lokiLanguageProvider} onChange={this.onChangeLogLabels} />
+          </div>
+        )}
         <LokiOptionFields
           queryType={query.instant ? 'instant' : 'range'}
           lineLimitValue={query?.maxLines?.toString() || ''}
