@@ -1,10 +1,12 @@
 import _ from 'lodash';
-import ResponseParser from './response_parser';
+import { Observable, of } from 'rxjs';
+import { catchError, map, mapTo } from 'rxjs/operators';
 import { getBackendSrv } from '@grafana/runtime';
 import { ScopedVars } from '@grafana/data';
-import { TemplateSrv } from 'app/features/templating/template_srv';
-import { TimeSrv } from 'app/features/dashboard/services/TimeSrv';
-//Types
+
+import ResponseParser, { MssqlResponse } from './response_parser';
+import { getTemplateSrv, TemplateSrv } from 'app/features/templating/template_srv';
+import { getTimeSrv, TimeSrv } from 'app/features/dashboard/services/TimeSrv';
 import { MssqlQueryForInterpolation } from './types';
 
 export class MssqlDatasource {
@@ -13,8 +15,11 @@ export class MssqlDatasource {
   responseParser: ResponseParser;
   interval: string;
 
-  /** @ngInject */
-  constructor(instanceSettings: any, private templateSrv: TemplateSrv, private timeSrv: TimeSrv) {
+  constructor(
+    instanceSettings: any,
+    private readonly templateSrv: TemplateSrv = getTemplateSrv(),
+    private readonly timeSrv: TimeSrv = getTimeSrv()
+  ) {
     this.name = instanceSettings.name;
     this.id = instanceSettings.id;
     this.responseParser = new ResponseParser();
@@ -34,7 +39,7 @@ export class MssqlDatasource {
       return value;
     }
 
-    const quotedValues = _.map(value, val => {
+    const quotedValues = _.map(value, (val) => {
       if (typeof value === 'number') {
         return value;
       }
@@ -50,11 +55,12 @@ export class MssqlDatasource {
   ): MssqlQueryForInterpolation[] {
     let expandedQueries = queries;
     if (queries && queries.length > 0) {
-      expandedQueries = queries.map(query => {
+      expandedQueries = queries.map((query) => {
         const expandedQuery = {
           ...query,
           datasource: this.name,
           rawSql: this.templateSrv.replace(query.rawSql, scopedVars, this.interpolateVariable),
+          rawQuery: true,
         };
         return expandedQuery;
       });
@@ -62,10 +68,10 @@ export class MssqlDatasource {
     return expandedQueries;
   }
 
-  query(options: any) {
-    const queries = _.filter(options.targets, item => {
+  query(options: any): Observable<MssqlResponse> {
+    const queries = _.filter(options.targets, (item) => {
       return item.hide !== true;
-    }).map(item => {
+    }).map((item) => {
       return {
         refId: item.refId,
         intervalMs: options.intervalMs,
@@ -77,11 +83,11 @@ export class MssqlDatasource {
     });
 
     if (queries.length === 0) {
-      return Promise.resolve({ data: [] });
+      return of({ data: [] });
     }
 
     return getBackendSrv()
-      .datasourceRequest({
+      .fetch({
         url: '/api/tsdb/query',
         method: 'POST',
         data: {
@@ -90,7 +96,7 @@ export class MssqlDatasource {
           queries: queries,
         },
       })
-      .then(this.responseParser.processQueryResult);
+      .pipe(map(this.responseParser.processQueryResult));
   }
 
   annotationQuery(options: any) {
@@ -106,7 +112,7 @@ export class MssqlDatasource {
     };
 
     return getBackendSrv()
-      .datasourceRequest({
+      .fetch({
         url: '/api/tsdb/query',
         method: 'POST',
         data: {
@@ -115,7 +121,8 @@ export class MssqlDatasource {
           queries: [query],
         },
       })
-      .then((data: any) => this.responseParser.transformAnnotationResponse(options, data));
+      .pipe(map((data: any) => this.responseParser.transformAnnotationResponse(options, data)))
+      .toPromise();
   }
 
   metricFindQuery(query: string, optionalOptions: { variable: { name: string } }) {
@@ -139,17 +146,18 @@ export class MssqlDatasource {
     };
 
     return getBackendSrv()
-      .datasourceRequest({
+      .fetch({
         url: '/api/tsdb/query',
         method: 'POST',
         data: data,
       })
-      .then((data: any) => this.responseParser.parseMetricFindQueryResult(refId, data));
+      .pipe(map((data: any) => this.responseParser.parseMetricFindQueryResult(refId, data)))
+      .toPromise();
   }
 
   testDatasource() {
     return getBackendSrv()
-      .datasourceRequest({
+      .fetch({
         url: '/api/tsdb/query',
         method: 'POST',
         data: {
@@ -167,17 +175,18 @@ export class MssqlDatasource {
           ],
         },
       })
-      .then((res: any) => {
-        return { status: 'success', message: 'Database Connection OK' };
-      })
-      .catch((err: any) => {
-        console.log(err);
-        if (err.data && err.data.message) {
-          return { status: 'error', message: err.data.message };
-        } else {
-          return { status: 'error', message: err.status };
-        }
-      });
+      .pipe(
+        mapTo({ status: 'success', message: 'Database Connection OK' }),
+        catchError((err) => {
+          console.error(err);
+          if (err.data && err.data.message) {
+            return of({ status: 'error', message: err.data.message });
+          }
+
+          return of({ status: 'error', message: err.status });
+        })
+      )
+      .toPromise();
   }
 
   targetContainsTemplate(target: any) {
