@@ -1,7 +1,7 @@
 import _ from 'lodash';
 import { QueryCtrl } from 'app/plugins/sdk';
 import { auto } from 'angular';
-import { PanelEvents } from '@grafana/data';
+import { PanelEvents, QueryResultMeta } from '@grafana/data';
 
 export interface MssqlQuery {
   refId: string;
@@ -10,10 +10,6 @@ export interface MssqlQuery {
   rawSql: string;
 }
 
-export interface QueryMeta {
-  sql: string;
-}
-
 const defaultQuery = `SELECT
   $__timeEpoch(<time_column>),
   <value column> as value,
@@ -28,11 +24,10 @@ ORDER BY
 export class MssqlQueryCtrl extends QueryCtrl {
   static templateUrl = 'partials/query.editor.html';
 
-  showLastQuerySQL: boolean;
   formats: any[];
   target: MssqlQuery;
-  lastQueryMeta: QueryMeta;
-  lastQueryError: string;
+  lastQueryMeta?: QueryResultMeta;
+  lastQueryError?: string;
   showHelp: boolean;
 
   /** @ngInject */
@@ -61,20 +56,14 @@ export class MssqlQueryCtrl extends QueryCtrl {
   }
 
   onDataReceived(dataList: any) {
-    this.lastQueryMeta = null;
-    this.lastQueryError = null;
-
-    const anySeriesFromQuery: any = _.find(dataList, { refId: this.target.refId });
-    if (anySeriesFromQuery) {
-      this.lastQueryMeta = anySeriesFromQuery.meta;
-    }
+    this.lastQueryError = undefined;
+    this.lastQueryMeta = dataList[0]?.meta;
   }
 
   onDataError(err: any) {
     if (err.data && err.data.results) {
       const queryRes = err.data.results[this.target.refId];
       if (queryRes) {
-        this.lastQueryMeta = queryRes.meta;
         this.lastQueryError = queryRes.error;
       }
     }
