@@ -1,20 +1,36 @@
 import _ from 'lodash';
+import { MysqlMetricFindValue } from './types';
+
+interface TableResponse extends Record<string, any> {
+  type: string;
+  refId: string;
+  meta: any;
+}
+
+interface SeriesResponse extends Record<string, any> {
+  target: string;
+  refId: string;
+  meta: any;
+  datapoints: [any[]];
+}
+
+export interface MysqlResponse {
+  data: Array<TableResponse | SeriesResponse>;
+}
 
 export default class ResponseParser {
-  constructor(private $q) {}
-
-  processQueryResult(res) {
-    var data = [];
+  processQueryResult(res: any): MysqlResponse {
+    const data: any[] = [];
 
     if (!res.data.results) {
       return { data: data };
     }
 
-    for (let key in res.data.results) {
-      let queryRes = res.data.results[key];
+    for (const key in res.data.results) {
+      const queryRes = res.data.results[key];
 
       if (queryRes.series) {
-        for (let series of queryRes.series) {
+        for (const series of queryRes.series) {
           data.push({
             target: series.name,
             datapoints: series.points,
@@ -25,7 +41,7 @@ export default class ResponseParser {
       }
 
       if (queryRes.tables) {
-        for (let table of queryRes.tables) {
+        for (const table of queryRes.tables) {
           table.type = 'table';
           table.refId = queryRes.refId;
           table.meta = queryRes.meta;
@@ -37,7 +53,7 @@ export default class ResponseParser {
     return { data: data };
   }
 
-  parseMetricFindQueryResult(refId, results) {
+  parseMetricFindQueryResult(refId: string, results: any): MysqlMetricFindValue[] {
     if (!results || results.data.length === 0 || results.data.results[refId].meta.rowCount === 0) {
       return [];
     }
@@ -54,7 +70,7 @@ export default class ResponseParser {
     return this.transformToSimpleList(rows);
   }
 
-  transformToKeyValueList(rows, textColIndex, valueColIndex) {
+  transformToKeyValueList(rows: any, textColIndex: number, valueColIndex: number) {
     const res = [];
 
     for (let i = 0; i < rows.length; i++) {
@@ -69,24 +85,23 @@ export default class ResponseParser {
     return res;
   }
 
-  transformToSimpleList(rows) {
+  transformToSimpleList(rows: any) {
     const res = [];
 
     for (let i = 0; i < rows.length; i++) {
       for (let j = 0; j < rows[i].length; j++) {
-        const value = rows[i][j];
-        if (res.indexOf(value) === -1) {
-          res.push(value);
-        }
+        res.push(rows[i][j]);
       }
     }
 
-    return _.map(res, value => {
+    const unique = Array.from(new Set(res));
+
+    return _.map(unique, (value) => {
       return { text: value };
     });
   }
 
-  findColIndex(columns, colName) {
+  findColIndex(columns: any[], colName: string) {
     for (let i = 0; i < columns.length; i++) {
       if (columns[i].text === colName) {
         return i;
@@ -96,7 +111,7 @@ export default class ResponseParser {
     return -1;
   }
 
-  containsKey(res, key) {
+  containsKey(res: any[], key: any) {
     for (let i = 0; i < res.length; i++) {
       if (res[i].text === key) {
         return true;
@@ -105,20 +120,23 @@ export default class ResponseParser {
     return false;
   }
 
-  transformAnnotationResponse(options, data) {
+  transformAnnotationResponse(options: any, data: any) {
     const table = data.data.results[options.annotation.name].tables[0];
 
     let timeColumnIndex = -1;
+    let timeEndColumnIndex = -1;
     let textColumnIndex = -1;
     let tagsColumnIndex = -1;
 
     for (let i = 0; i < table.columns.length; i++) {
       if (table.columns[i].text === 'time_sec' || table.columns[i].text === 'time') {
         timeColumnIndex = i;
+      } else if (table.columns[i].text === 'timeend') {
+        timeEndColumnIndex = i;
       } else if (table.columns[i].text === 'title') {
-        return this.$q.reject({
+        throw {
           message: 'The title column for annotations is deprecated, now only a column named text is returned',
-        });
+        };
       } else if (table.columns[i].text === 'text') {
         textColumnIndex = i;
       } else if (table.columns[i].text === 'tags') {
@@ -127,17 +145,20 @@ export default class ResponseParser {
     }
 
     if (timeColumnIndex === -1) {
-      return this.$q.reject({
+      throw {
         message: 'Missing mandatory time column (with time_sec column alias) in annotation query.',
-      });
+      };
     }
 
     const list = [];
     for (let i = 0; i < table.rows.length; i++) {
       const row = table.rows[i];
+      const timeEnd =
+        timeEndColumnIndex !== -1 && row[timeEndColumnIndex] ? Math.floor(row[timeEndColumnIndex]) : undefined;
       list.push({
         annotation: options.annotation,
         time: Math.floor(row[timeColumnIndex]),
+        timeEnd,
         text: row[textColumnIndex] ? row[textColumnIndex].toString() : '',
         tags: row[tagsColumnIndex] ? row[tagsColumnIndex].trim().split(/\s*,\s*/) : [],
       });
