@@ -50,14 +50,14 @@ export default class PrometheusMetricFindQuery {
   labelNamesQuery() {
     const start = this.datasource.getPrometheusTime(this.range.from, false);
     const end = this.datasource.getPrometheusTime(this.range.to, true);
-    const params = new URLSearchParams({
+    const params = {
       start: start.toString(),
       end: end.toString(),
-    });
+    };
 
-    const url = `/api/v1/labels?${params.toString()}`;
+    const url = `/api/v1/labels`;
 
-    return this.datasource.metadataRequest(url).then((result: any) => {
+    return this.datasource.metadataRequest(url, params).then((result: any) => {
       return _.map(result.data.data, (value) => {
         return { text: value };
       });
@@ -71,27 +71,27 @@ export default class PrometheusMetricFindQuery {
     let url: string;
 
     if (!metric) {
-      const params = new URLSearchParams({
+      const params = {
         start: start.toString(),
         end: end.toString(),
-      });
+      };
       // return label values globally
-      url = `/api/v1/label/${label}/values?${params.toString()}`;
+      url = `/api/v1/label/${label}/values`;
 
-      return this.datasource.metadataRequest(url).then((result: any) => {
+      return this.datasource.metadataRequest(url, params).then((result: any) => {
         return _.map(result.data.data, (value) => {
           return { text: value };
         });
       });
     } else {
-      const params = new URLSearchParams({
+      const params = {
         'match[]': metric,
         start: start.toString(),
         end: end.toString(),
-      });
-      url = `/api/v1/series?${params.toString()}`;
+      };
+      url = `/api/v1/series`;
 
-      return this.datasource.metadataRequest(url).then((result: any) => {
+      return this.datasource.metadataRequest(url, params).then((result: any) => {
         const _labels = _.map(result.data.data, (metric) => {
           return metric[label] || '';
         }).filter((label) => {
@@ -111,13 +111,13 @@ export default class PrometheusMetricFindQuery {
   metricNameQuery(metricFilterPattern: string) {
     const start = this.datasource.getPrometheusTime(this.range.from, false);
     const end = this.datasource.getPrometheusTime(this.range.to, true);
-    const params = new URLSearchParams({
+    const params = {
       start: start.toString(),
       end: end.toString(),
-    });
-    const url = `/api/v1/label/__name__/values?${params.toString()}`;
+    };
+    const url = `/api/v1/label/__name__/values`;
 
-    return this.datasource.metadataRequest(url).then((result: any) => {
+    return this.datasource.metadataRequest(url, params).then((result: any) => {
       return _.chain(result.data.data)
         .filter((metricName) => {
           const r = new RegExp(metricFilterPattern);
@@ -161,16 +161,16 @@ export default class PrometheusMetricFindQuery {
   metricNameAndLabelsQuery(query: string): Promise<MetricFindValue[]> {
     const start = this.datasource.getPrometheusTime(this.range.from, false);
     const end = this.datasource.getPrometheusTime(this.range.to, true);
-    const params = new URLSearchParams({
+    const params = {
       'match[]': query,
       start: start.toString(),
       end: end.toString(),
-    });
+    };
 
-    const url = `/api/v1/series?${params.toString()}`;
+    const url = `/api/v1/series`;
     const self = this;
 
-    return this.datasource.metadataRequest(url).then((result: any) => {
+    return this.datasource.metadataRequest(url, params).then((result: any) => {
       return _.map(result.data.data, (metric: { [key: string]: string }) => {
         return {
           text: self.datasource.getOriginalMetricName(metric),
