@@ -1,4 +1,3 @@
-import '../module';
 import { GraphCtrl } from '../module';
 import { MetricsPanelCtrl } from 'app/features/panel/metrics_panel_ctrl';
 import { PanelCtrl } from 'app/features/panel/panel_ctrl';
@@ -79,6 +78,9 @@ describe('grafanaGraph', () => {
         tooltip: {
           shared: true,
         },
+        fieldConfig: {
+          defaults: {},
+        },
       },
       renderingCompleted: jest.fn(),
       hiddenSeries: {},
