@@ -10,12 +10,12 @@ export * from './datasources';
 export * from './plugins';
 export * from './organization';
 export * from './appNotifications';
-export * from './search';
 export * from './explore';
 export * from './store';
 export * from './ldap';
 export * from './appEvent';
 export * from './angular';
+export * from './query';
 
 import * as CoreEvents from './events';
 export { CoreEvents };
